﻿using Caliburn.Micro;
using System;
using System.ComponentModel.Composition;
using System.Windows;
using VisualComponents.Create3D;
using VisualComponents.UX.Shared;

namespace Plugin.ContextChange
{
    /// <summary>
    /// This class is example of how we can create extended "Context" in addition to configur,teach,author and drawing context.
    /// </summary>
    [Export(typeof(IContext))]
    [PartCreationPolicy(CreationPolicy.Shared)]
    internal class CustomContext : BaseContext, IContext, IHandle<ApplicationContextChangedMessage>
    {
        private RibbonTab _activeTab;
        private readonly IApplicationContext _appContext;
        private readonly IApplication _application;
        private readonly IEventAggregator _eventAggregator;

        [ImportingConstructor]
        public CustomContext([Import]IEventAggregator eventAggregator)
        {
            AddSupportedManipulationMode(ManipulationMode.Select);
            AddSupportedManipulationMode(ManipulationMode.Move);
            _eventAggregator = eventAggregator;
            _application = IoC.Get<IApplication>();
            _application.InitializedChanged += _application_InitializedChanged;
            _appContext = IoC.Get<IApplicationContext>();
        }

        private void _application_InitializedChanged(object sender, System.EventArgs e)
        {
            var _ribbonVM = IoC.Get<IRibbonViewModel>();
            _ribbonVM.RibbonTabSelected += OnRibbonTabSelected;
            _eventAggregator.Subscribe(this);
        }

        private void OnRibbonTabSelected(object o, RibbonTabSelectedEventArgs e)
        {
            if (e.NewSelectedRibbonTabItem != null)
            {
                _activeTab = e.NewSelectedRibbonTabItem;
                string name = _activeTab.Name;
                switch (name)
                {
                    case "CustomRibbon":
                        try
                        {
                            _appContext.SetContext("CustomRibbonContext");
                        }
                        catch (ArgumentException ex)
                        {

                        }
                        break;
                }
            }

        }

        public string Id
        {
            get { return "CustomRibbonContext"; }
        }

        /// <summary>
        /// Represents if this context is active.
        /// </summary>
        public new bool IsActive
        {
            get;
            private set;
        }

        /// <summary>
        /// Method called when this context is activated.
        /// </summary>
        public new void Activate()
        {
            IsActive = true;
        }

        /// <summary>
        /// method called when this context is deactivated.
        /// </summary>
        public new void Deactivate()
        {
            IsActive = false;
        }

        /// <summary>
        /// This method is called when context change happens.
        /// </summary>
        /// <param name="message"></param>
        public void Handle(ApplicationContextChangedMessage message)
        {
            if (message.NewContext.Id == "CustomRibbonContext")
            {
                VcMessageBox.Show(string.Format("Now it is in {0} .You can do Some staffs here!", message.NewContext.Id), "Testing...", MessageBoxButton.OK, MessageBoxImage.Information);
            }
            else
            {
                VcMessageBox.Show(string.Format("Now it is in {0} .", message.NewContext.Id), "Testing...", MessageBoxButton.OK, MessageBoxImage.Information);
            }
        }
    }
}
